@@ -1504,6 +1504,15 @@ void _init_char(PyObject *m)
     INSTALL_ENUM(UBlockCode, "UNIFIED_CANADIAN_ABORIGINAL_SYLLABICS_EXTENDED_A", UBLOCK_UNIFIED_CANADIAN_ABORIGINAL_SYLLABICS_EXTENDED_A);
     INSTALL_ENUM(UBlockCode, "VITHKUQI", UBLOCK_VITHKUQI);
     INSTALL_ENUM(UBlockCode, "ZNAMENNY_MUSICAL_NOTATION", UBLOCK_ZNAMENNY_MUSICAL_NOTATION);
+#endif
+#if U_ICU_VERSION_HEX >= VERSION_HEX(72, 0, 0)
+    INSTALL_ENUM(UBlockCode, "ARABIC_EXTENDED_C", UBLOCK_ARABIC_EXTENDED_C);
+    INSTALL_ENUM(UBlockCode, "CJK_UNIFIED_IDEOGRAPHS_EXTENSION_H", UBLOCK_CJK_UNIFIED_IDEOGRAPHS_EXTENSION_H);
+    INSTALL_ENUM(UBlockCode, "CYRILLIC_EXTENDED_D", UBLOCK_CYRILLIC_EXTENDED_D);
+    INSTALL_ENUM(UBlockCode, "DEVANAGARI_EXTENDED_A", UBLOCK_DEVANAGARI_EXTENDED_A);
+    INSTALL_ENUM(UBlockCode, "KAKTOVIK_NUMERALS", UBLOCK_KAKTOVIK_NUMERALS);
+    INSTALL_ENUM(UBlockCode, "KAWI", UBLOCK_KAWI);
+    INSTALL_ENUM(UBlockCode, "NAG_MUNDARI", UBLOCK_NAG_MUNDARI);
 #endif
     INSTALL_ENUM(UBlockCode, "INVALID_CODE", UBLOCK_INVALID_CODE);
 
