@@ -1,5 +1,5 @@
 /* ====================================================================
- * Copyright (c) 2005-2019 Open Source Applications Foundation.
+ * Copyright (c) 2005-2022 Open Source Applications Foundation.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -33,6 +33,10 @@
 #include "bases.h"
 #include "macros.h"
 
+// From Python's Objects/unicodeobject.c
+// Maximum code point of Unicode 6.0: 0x10ffff (1,114,111).
+#define MAX_UNICODE 0x10ffff
+
 static PyObject *utcoffset_NAME;
 static PyObject *toordinal_NAME;
 static PyObject *getDefault_NAME;
@@ -209,6 +213,8 @@ EXPORT PyObject *PyUnicode_FromUnicodeString(const UChar *utf16, int len16)
             max_char |= cp;  // we only care about the leftmost bit
             len32 += 1;
         }
+        if (max_char > MAX_UNICODE)
+            max_char = MAX_UNICODE;
 
         PyObject *result = PyUnicode_New(len32, max_char);
 
