@@ -169,6 +169,7 @@ typedef intintobjargproc ssizessizeobjargproc;
 #include <unicode/ucasemap.h>
 #include <unicode/udata.h>
 #include <unicode/ubidi.h>
+#include <unicode/uclean.h>
 
 #define VERSION_HEX(major, minor, patch) \
   (((major) << 24) | ((minor) << 16) | ((patch) << 8))
@@ -264,6 +265,10 @@ typedef intintobjargproc ssizessizeobjargproc;
 #include <unicode/localematcher.h>
 #endif
 
+#if U_ICU_VERSION_HEX >= VERSION_HEX(72, 0, 0)
+#include <unicode/displayoptions.h>
+#endif
+
 #if U_ICU_VERSION_HEX < 0x04060000
 
 typedef UClassID classid;
@@ -345,7 +350,7 @@ public:
 };
 
 EXPORT PyObject *PyUnicode_FromUnicodeString(const UnicodeString *string);
-EXPORT PyObject *PyUnicode_FromUnicodeString(const UChar *chars, int size);
+EXPORT PyObject *PyUnicode_FromUnicodeString(const UChar *utf16, int len16);
 
 EXPORT UnicodeString &PyBytes_AsUnicodeString(PyObject *object,
                                               const char *encoding,
