@@ -99,30 +99,30 @@ static PyObject *t_locale_addLikelySubtags(t_locale *self);
 static PyObject *t_locale_minimizeSubtags(t_locale *self);
 #endif
 #if U_ICU_VERSION_HEX >= 0x04040000
-static PyObject *t_locale_getRoot(PyTypeObject *type);
+static PyObject *t_locale_getRoot(PyTypeObject *self);
 #endif
-static PyObject *t_locale_getEnglish(PyTypeObject *type);
-static PyObject *t_locale_getFrench(PyTypeObject *type);
-static PyObject *t_locale_getGerman(PyTypeObject *type);
-static PyObject *t_locale_getItalian(PyTypeObject *type);
-static PyObject *t_locale_getJapanese(PyTypeObject *type);
-static PyObject *t_locale_getKorean(PyTypeObject *type);
-static PyObject *t_locale_getChinese(PyTypeObject *type);
-static PyObject *t_locale_getSimplifiedChinese(PyTypeObject *type);
-static PyObject *t_locale_getTraditionalChinese(PyTypeObject *type);
-static PyObject *t_locale_getFrance(PyTypeObject *type);
-static PyObject *t_locale_getGermany(PyTypeObject *type);
-static PyObject *t_locale_getItaly(PyTypeObject *type);
-static PyObject *t_locale_getJapan(PyTypeObject *type);
-static PyObject *t_locale_getKorea(PyTypeObject *type);
-static PyObject *t_locale_getChina(PyTypeObject *type);
-static PyObject *t_locale_getPRC(PyTypeObject *type);
-static PyObject *t_locale_getTaiwan(PyTypeObject *type);
-static PyObject *t_locale_getUK(PyTypeObject *type);
-static PyObject *t_locale_getUS(PyTypeObject *type);
-static PyObject *t_locale_getCanada(PyTypeObject *type);
-static PyObject *t_locale_getCanadaFrench(PyTypeObject *type);
-static PyObject *t_locale_getDefault(PyTypeObject *type);
+static PyObject *t_locale_getEnglish(PyTypeObject *self);
+static PyObject *t_locale_getFrench(PyTypeObject *self);
+static PyObject *t_locale_getGerman(PyTypeObject *self);
+static PyObject *t_locale_getItalian(PyTypeObject *self);
+static PyObject *t_locale_getJapanese(PyTypeObject *self);
+static PyObject *t_locale_getKorean(PyTypeObject *self);
+static PyObject *t_locale_getChinese(PyTypeObject *self);
+static PyObject *t_locale_getSimplifiedChinese(PyTypeObject *self);
+static PyObject *t_locale_getTraditionalChinese(PyTypeObject *self);
+static PyObject *t_locale_getFrance(PyTypeObject *self);
+static PyObject *t_locale_getGermany(PyTypeObject *self);
+static PyObject *t_locale_getItaly(PyTypeObject *self);
+static PyObject *t_locale_getJapan(PyTypeObject *self);
+static PyObject *t_locale_getKorea(PyTypeObject *self);
+static PyObject *t_locale_getChina(PyTypeObject *self);
+static PyObject *t_locale_getPRC(PyTypeObject *self);
+static PyObject *t_locale_getTaiwan(PyTypeObject *self);
+static PyObject *t_locale_getUK(PyTypeObject *self);
+static PyObject *t_locale_getUS(PyTypeObject *self);
+static PyObject *t_locale_getCanada(PyTypeObject *self);
+static PyObject *t_locale_getCanadaFrench(PyTypeObject *self);
+static PyObject *t_locale_getDefault(PyTypeObject *self);
 static PyObject *t_locale_setDefault(PyTypeObject *type, PyObject *args);
 static PyObject *t_locale_createFromName(PyTypeObject *type, PyObject *args);
 #if U_ICU_VERSION_HEX >= VERSION_HEX(63, 0, 0)
@@ -248,6 +248,7 @@ static PyObject *t_resourcebundle_getIntVector(t_resourcebundle *self);
 static PyObject *t_resourcebundle_getLocale(t_resourcebundle *self,
                                             PyObject *args);
 
+static PyObject *t_resourcebundle_resetICU(PyTypeObject *type);
 #ifndef PYPY_VERSION
 static PyObject *t_resourcebundle_setAppData(PyTypeObject *type,
                                              PyObject *args);
@@ -272,6 +273,7 @@ static PyMethodDef t_resourcebundle_methods[] = {
     DECLARE_METHOD(t_resourcebundle, getBinary, METH_NOARGS),
     DECLARE_METHOD(t_resourcebundle, getIntVector, METH_NOARGS),
     DECLARE_METHOD(t_resourcebundle, getLocale, METH_VARARGS),
+    DECLARE_METHOD(t_resourcebundle, resetICU, METH_CLASS | METH_NOARGS),
 #ifndef PYPY_VERSION
     DECLARE_METHOD(t_resourcebundle, setAppData, METH_CLASS | METH_VARARGS),
 #endif
@@ -434,7 +436,7 @@ using LocaleMatcherResult = LocaleMatcher::Result;
 
 class t_localematcherbuilder : public _wrapper {
 public:
-  LocaleMatcherBuilder *object;
+    LocaleMatcherBuilder *object;
 };
 
 static int t_localematcherbuilder_init(t_localematcherbuilder *self, PyObject *args, PyObject *kwds);
@@ -1572,6 +1574,17 @@ static PyObject *t_resourcebundle_getLocale(t_resourcebundle *self,
     return PyErr_SetArgsError((PyObject *) self, "getLocale", args);
 }
 
+// Use this with care, see docs for u_cleanup() and u_init() in uclean.h or at
+// https://unicode-org.github.io/icu-docs/apidoc/dev/icu4c/uclean_8h.html
+static PyObject *t_resourcebundle_resetICU(PyTypeObject *type)
+{
+    u_cleanup();
+    STATUS_CALL(u_init(&status));
+
+    Py_RETURN_NONE;
+}
+
+
 #ifndef PYPY_VERSION
 #if defined(_MSC_VER) || defined(__WIN32)
 
