@@ -279,6 +279,12 @@ static PyObject *t_measureunit_createMilligramOfglucosePerDeciliter(PyTypeObject
 
 #if U_ICU_VERSION_HEX >= VERSION_HEX(70, 0, 0)
 static PyObject *t_measureunit_createKilowattHourPer100Kilometer(PyTypeObject *type);
+static PyObject *t_measureunit_createItem(PyTypeObject *type);
+#endif
+
+#if U_ICU_VERSION_HEX >= VERSION_HEX(72, 0, 0)
+static PyObject *t_measureunit_createQuarter(PyTypeObject *type);
+static PyObject *t_measureunit_createTonne(PyTypeObject *type);
 #endif
 
 static PyMethodDef t_measureunit_methods[] = {
@@ -509,6 +515,11 @@ static PyMethodDef t_measureunit_methods[] = {
 #endif
 #if U_ICU_VERSION_HEX >= VERSION_HEX(70, 0, 0)
     DECLARE_METHOD(t_measureunit, createKilowattHourPer100Kilometer, METH_NOARGS | METH_CLASS),
+    DECLARE_METHOD(t_measureunit, createItem, METH_NOARGS | METH_CLASS),
+#endif
+#if U_ICU_VERSION_HEX >= VERSION_HEX(72, 0, 0)
+    DECLARE_METHOD(t_measureunit, createQuarter, METH_NOARGS | METH_CLASS),
+    DECLARE_METHOD(t_measureunit, createTonne, METH_NOARGS | METH_CLASS),
 #endif
     { NULL, NULL, 0, NULL }
 };
@@ -1125,6 +1136,12 @@ createMU(MilligramOfglucosePerDeciliter)
 
 #if U_ICU_VERSION_HEX >= VERSION_HEX(70, 0, 0)
 createMU(KilowattHourPer100Kilometer)
+createMU(Item)
+#endif
+
+#if U_ICU_VERSION_HEX >= VERSION_HEX(72, 0, 0)
+createMU(Quarter)
+createMU(Tonne)
 #endif
 
 /* Measure */
