@@ -585,6 +585,10 @@ void _init_script(PyObject *m)
     INSTALL_ENUM(UScriptCode, "TOTO", USCRIPT_TOTO);
     INSTALL_ENUM(UScriptCode, "VITHKUQI", USCRIPT_VITHKUQI);
 #endif
+#if U_ICU_VERSION_HEX >= VERSION_HEX(72, 0, 0)
+    INSTALL_ENUM(UScriptCode, "KAWI", USCRIPT_KAWI);
+    INSTALL_ENUM(UScriptCode, "NAG_MUNDARI", USCRIPT_NAG_MUNDARI);
+#endif
 
 #if U_ICU_VERSION_HEX >= VERSION_HEX(51, 0, 0)
     INSTALL_ENUM(UScriptUsage, "NOT_ENCODED", USCRIPT_USAGE_NOT_ENCODED);
